.. _faq:

===========================
Frequently Asked Questions
===========================

.. contents:: :local:

How can I add a question here?
------------------------------

See `Contributing <contributing.rst>`_ for how to report bugs and ask questions. (hint: open a github issue)


How should I cite snowline?
------------------------------

Please cite these two papers:

* https://ui.adsabs.harvard.edu/abs/1975CoPhC..10..343J/abstract
* https://ui.adsabs.harvard.edu/abs/2013arXiv1304.7808B/abstract

They describe the underlying techniques.

A paper describing snowline may be published in the future.
